function [p, sig, t_a] = platepressure(coo, L,T, B,v, rho_ch, ...
                                    H_air,C_b, f_1, C_w, R_, T0, K, ...
                                    paneldef, D,~)                          
% This program calculates the pressure connected to the panels
%defined in the geometry matrix coo and other user input. Not all pressures
%has been concidered.  P=kN/m^2. DNV Rules for Ships over 100 meter, 
%January 2013.

%INPUT;
%some innitial calculations sec.4
g_0=9.81;           %Constant of gravity    [m/s^2]
rho=1.025;          %Dencity of sea water   [t/m^3]
R=R_/10;            %Reduction parameter  [-]    
L1=min(L,300);
%Create empty pressure vector
paneln=length(coo(:,1));%Number of panels
p=zeros(paneln,2);      %Dim. pressure and explanation
sig=zeros(paneln,1);    %Dim. plate tension

%thickness coefficients, some given as constants by uset input, others
%depend on position
t_a=zeros(paneln,2);

%% Initial calculations needed later
%Height at top corner, y-coordinat.
    H_ship=D;
%Air pipe heigth over baceline [m]
h_air=H_air+H_ship;  
%Section 4 Design loads
%B203 Common acceleration parameter
C_v=min(0.2,sqrt(L)/50);
C_v1=max(0.8, v/sqrt(L));
%Not affected by restricted service
a0=3*C_w/L+C_v*C_v1;
%B600 Combined vertical acceleration. Hold kv constant as a simplification
%interrested in.
kv=0.7;                        %Constant between 0.3-0.6 from A.P
av=kv*g_0*a0/C_b;
%C200 Sea pressure calculations
%Constant between 0.2L and 0.7L from AP
ks=2;                        
%The smallest of T and the vertical distance from waterline to top of ship side,max 0.8*Cw
kf=min(T,min(0.8*C_w,H_ship-T));               
% Parameter for calculating p_dp
if v/sqrt(L)<=1.5
    p_l=ks*C_w+kf;
else
    p_l=(ks*C_w+kf)*(0.8+0.15*(v/sqrt(L)));
end
%Some simplifications of parameters. Descriprion found under the different
%Design load tables. 
p_0=25;     % 25 in general, 15 in ballast for dry cargo vessels.
delta_p=25;  % 25 for ballast tanks, 0 for others tanks. (Page 58)

%% Pressure calculation
%Go through the panels and find the highest pressure for each panel
test=zeros(paneln,3);

for i=1:paneln
    %initial values for each panel - Assume load point at lowest point
    %Dynamic pressure
    p_dp=dynpressure(coo(i,:),B,T,p_l);
    %Vertical distance from waterline at draught T to load point
    h_0=abs(T-min(coo(i,2),coo(i,4)));   
    %Distance from load point to top of tank and tank breadth, works for
    %horizontal beams
    [h_s,~]=tankheight(coo(i,1), coo(i,2),coo(i,3), coo(i,4), coo); 
    %Distance from load point to top of air pipe
    h_p=h_air-coo(i,2);  
    %Section 6 Bottom Structure   
    if strcmp(paneldef(i),'KEEL')==1 || strcmp(paneldef(i),'BOTTOM_OUT')==1
        %Sea pressure P1 (sec 6, Table B1) 
        p1=(10*h_0+p_dp)*(1-R);
        %Net pressure in way of cargo single bottom pressure? XXX
        %tank or deep tank
        %p2=rho*(g_0+0.5*av)*h_s-10*(0.35*T); 
        %p3=rho*g_0*h_s+p_0-10*(0.35*T);
        p(i,1)=p1;
        sig(i)=120*f_1;  %When longitudenal frames constant

        if strcmp(paneldef(i),'KEEL')==1
        t_a(i,:)=[7 0.05];              %Keel parameters - konstant
        p(i,2)=1;
        else 
        t_a(i,:)=[5 0.04];              %Outer bottom  - konstant
        p(i,2)=2;
        end
        
    %Inner bottom plating C400 (p4-p15)
    elseif strncmp(paneldef(i),'BOTTOM_IN',9)==1 
        %inner bottom, floors and keel, horisontal elements
  
        %dry cargo in cargo holds: p4
        %Dependent on cargo heigth H_c
        if strcmp(paneldef(i),'BOTTOM_IN_C')==1
        p4=rho_ch*(g_0+0.5*av);
        p(i,1)=p4;
        p(i,2)=3;
        sig(i)=140*f_1; %when longditudenal frames within 0.4L
        t_a(i,:)=[7 0.03]; %Koefficient constant XXX finf fitting t_0
        
        elseif strcmp(paneldef(i),'BOTTOM_IN_G')==1%BOTTOM_IN_G
    %Plating in double bottom floors and longitudenal girder C500 (p13-p15)
    %Worst case: take the pressure at the bottom.
        h_s=coo(i,4)-coo(i,2); % tankheigth not good with vertical panels.
        p13=0.67*(10*h_p+delta_p);
        p14=rho*g_0*h_s+p_0;       
        p(i,1)=max(p13,p14);
        sig(i)=130*f_1; %Longit. stiffened longitudenal girder within 0.4L
        
        if coo(i,1)==0 && coo(i,3)==0
        t_a(i,:)=[6 0.04]; %Max value: for center girder up to 2m above keel
        p(i,2)=4;           % Plating in double bottom, center girder
        else 
        t_a(i,:)=[6 0.02]; 
        p(i,2)=5;           % Plating in double bottom, out of center
        end
        
        else %Bottom in sides- probably ballast
            p5=(10+0.5*av)*h_s;
            p7=0.67*(10*h_p+delta_p);
            p8=10*h_s+p_0;
            p(i,1)=max([p5 p7 p8]);
            sig(i)=140*f_1;
            p(i,2)=6; %inner bottom beside cargo
            t_a(i,:)=[6 0.03];      %otherwhere in hold if cieling is not fitted? xxx    
        end
    %Section 7 Side Structures
    %Side plating, general (p1-p8)
    elseif strncmp(paneldef(i),'SIDE',4)==1
                if coo(i,2)<(T+4.6)           % Below summer waterline +4.6
                    t_a(i,:)=[5 0.04];
                elseif  (T+4.6+2.3)<coo(i,2)<=(T+4.6+2*2.3)
                    t_a(i,:)=[5 0.03];
                elseif (T+4.6+2*2.3)<coo(i,2)<=(T+4.6+3*2.3)
                    t_a(i,:)=[5 0.02];
                else
                    t_a(i,:)=[5 0.01];
                end
        sig(i)=140*f_1; %For longitudenal stiffened side plating (simpification) xxx        
        %External
        if strcmp(paneldef(i),'SIDE_EXT')==1
            %Reduction because of service restruction
        p1=10*h_0+p_dp*(1-R);
        p2=max((p_dp-(4+0.2*ks)*h_0)*(1-R),6.250+0.025*L1);
        
            if coo(i,2)<T % Below summer waterline
                p(i,1)=p1;
                p(i,2)=4; %External side under water
            else
                p(i,1)=p2;
                p(i,2)=5; %External side over water
            end
        %internal
        else              
            if coo(i,2)<T % ballast water line = T
            h_b=0.35*T-coo(i,2); %Distance from the load point to the minimum design draugth. page 103
            else
                h_b=0;
            end
        p3=rho*(g_0+0.5*av)*h_s-10*h_b+p_0;
        p4=rho*g_0*h_s-10*h_b+p_0;
        p5=0.067*(rho*g_0*h_p+delta_p)-10*h_b;
        p(i,1)=max([p3 p4 p5]);
        p(i,2)=6; %Internal side, cargo depencence
        end
           
     %section 8 Deck structure
     %Strength deck plating (p1-p13)
    elseif strncmp(paneldef(i),'DECK',4)==1
            
        if strcmp(paneldef(i),'DECK_ST')==1 %STRENGTH DECK
        h_0=H_ship-T; 
        p1=max(0.8*(p_dp-(4+.2*ks)*h_0)*(1-R),5);
        
             p(i,1)=p1;
             p(i,2)=7; %Strength deck, sea pressure         
             sig(i)=120*f_1; %longitudenally stiffened          
             t_a(i,:)=[5.5 0.02]; %Pick the max values

        else %Deck top or bottom
            p6=rho*(g_0+0.5*av)*h_s;
            p7=0.67*(rho*g_0*h_p+delta_p);
            p8=rho*g_0*h_s+p_0;
            
            p(i,1)=max([p6 p7 p8]);
            sig(i)=120*f_1; %longitudenally stiffened
            p(i,2)=12;
            t_a(i,:)=[5.5 0.00]; %Pick the max values
        end
    elseif strcmp(paneldef(i),'BULKHEAD')==1
        	p5=rho*g_0*h_s+p_0;
            p3=rho*(g_0+0.5*av)*h_s;
            p4=0.67*(rho*g_0*h_p+delta_p);
            
            p(i,1)=max([p5 p3 p4]);
            sig(i)=160*f_1; %longitudenally stiffened
            p(i,2)=13;
            t_a(i,:)=[5 0.03]; %Longitudenal bulkheads
        
    else
        p(i,1)=0;
    end   
    
    %If T0 and K given as input, these values override the program values:
    if T0~=0 
        t_a(i,1)=T0;
    end
    
    if  K~=0
        t_a(i,2)=K;
    end
    
   %test(i,:)=[h_s h_p h_0];  
end
end
