function[Z]=sec_modH(tb,lb,tt,lt,h_w,t_w,S)
%Calculates the section modulus of a H-beam. All input must be in m.

ab1=0.6*S/lb; %length flange bottom
ab2=0.6*S/lt; %length flange top
%formula for effective bredt based on DNV table C2, Pt.3 Ch.1 Sec.3
b_ecb=lb*(-0.0525*ab1^2+0.4385*ab1-0.0015); %Effective plate flange
b_ect=lt*(-0.0525*ab2^2+0.4385*ab2-0.0015);
%girder in ship y diraction
%Center of parts
%bottom flange
z_bf=tb/2;          %1 x
z_w=h_w/2+tb;       %2 x
z_tf=tt/2+h_w+tb;   %3 x 

A1=tb*b_ecb; % x^2
Av1=A1*z_bf;   % x^3
A2=h_w*t_w;
Av2=A2*z_w;
A3=tt*b_ect;
Av3=A3*z_tf;

zn=(Av1+Av2+Av3)/(A1+A2+A3);

Ix1=b_ecb*tb^3/12; % x^4
Ix2=t_w*h_w^3/12;
Ix3=b_ect*tt^3/12;

A=[A1,A2,A3];
z=[z_bf, z_w,z_tf];
Ix=[Ix1,Ix2,Ix3];

%Moment of inertia z axis
Sb=[0,0,0];
I_xt=[0,0,0];
for i=1:3
    Sb(i)=(A(i)* (z(i)-zn)^2);     
    I_xt(i) = Ix(i) + Sb(i) ; 
end
hight=(tb+tt+h_w);
Z = sum(I_xt)/(max(zn,(hight-zn))); %x^3

